@@ -53,12 +53,17 @@ class MountManager(object):
         return input_buffer
 
     def _iter_volume_mount_points(self, volume):
+        from infi.wioctl.errors import WindowsException
         input_buffer = self._create_input_buffer_for_query_points_ioctl(volume)
-        output_buffer = self._io.ioctl_mountmgr_query_points(input_buffer, len(input_buffer) + 1)
-        struct = structures.MOUNTMGR_MOUNT_POINTS.create_from_string(output_buffer)
-        for item in struct.MountPoints:
-            offset, length = item.SymbolicLinkNameOffset, item.SymbolicLinkNameLength
-            yield _slice_unicode_string_from_buffer(output_buffer, offset, length)
+        try:
+            output_buffer = self._io.ioctl_mountmgr_query_points(input_buffer, len(input_buffer) + 1)
+        except WindowsException:
+            return
+        else:
+            struct = structures.MOUNTMGR_MOUNT_POINTS.create_from_string(output_buffer)
+            for item in struct.MountPoints:
+                offset, length = item.SymbolicLinkNameOffset, item.SymbolicLinkNameLength
+                yield _slice_unicode_string_from_buffer(output_buffer, offset, length)
 
     def get_volume_guid(self, volume):
         # there must be a volume guid
